---
title: 리디렉션이란?
description: 리디렉션의 정의를 자세히 확인할수 있습니다.
targetVersions:
  - v1
---

**현재 페이지를 다른 페이지로 이동함을 의미합니다.**

![](</gitbook-assets/ko/image (145).png>)

## 리디렉션은 왜 필요할까요?

- 기존의 페이지의 주소가 새롭게 변경되어 이동이 필요한 경우
- 불필요하거나 잘못된 서브 주소를 하나로 이동시키는 경우
- 로그인, 인증 등의 목적으로 다른 주소로 이동이 필요한 경우

**리디렉션은 아래와 같이 두 가지로 구분이 됩니다.**

- **리디렉션 301**

  - 서버사이드 및 클라이언트 언어에서 어떤 코드도 수행하지 않고 바로 리디렉션 처리

- **리디렉션 302**

  - 일시적인 방법으로 Redirect으로 스크립트나 html 태그를 이용한 방법
